@@ -24,6 +24,7 @@ import logging
 import time
 import ldap
 import ldap.sasl
+import urllib
 
 from nss_cache import error
 from nss_cache.maps import automount
@@ -31,12 +32,13 @@ from nss_cache.maps import group
 from nss_cache.maps import netgroup
 from nss_cache.maps import passwd
 from nss_cache.maps import shadow
+from nss_cache.maps import sshkey
 from nss_cache.sources import source
 
 def RegisterImplementation(registration_callback):
   registration_callback(LdapSource)
-  
-  
+
+
 class LdapSource(source.Source):
   """Source for data in LDAP.
 
@@ -95,6 +97,10 @@ class LdapSource(source.Source):
 
   def _SetDefaults(self, configuration):
     """Set defaults if necessary."""
+    # LDAPI URLs must be url escaped socket filenames; rewrite if necessary.
+    if 'uri' in configuration:
+      if configuration['uri'].startswith('ldapi://'):
+        configuration['uri'] = 'ldapi://' + urllib.quote(configuration['uri'][8:], '')
     if not 'bind_dn' in configuration:
       configuration['bind_dn'] = self.BIND_DN
     if not 'bind_password' in configuration:
@@ -131,7 +137,7 @@ class LdapSource(source.Source):
       configuration['tls_require_cert'] = ldap.OPT_X_TLS_ALLOW
     elif configuration['tls_require_cert'] == 'try':
       configuration['tls_require_cert'] = ldap.OPT_X_TLS_TRY
-    
+
     if not 'sasl_authzid' in configuration:
       configuration['sasl_authzid'] = ''
 
@@ -254,6 +260,21 @@ class LdapSource(source.Source):
         else:
           yield record[1]
 
+  def GetSshkeyMap(self, since=None):
+    """Return the sshkey map from this source.
+
+    Args:
+      since: Get data only changed since this timestamp (inclusive) or None
+      for all data.
+
+    Returns:
+      instance of maps.SshkeyMap
+    """
+    return SshkeyUpdateGetter().GetUpdates(source=self,
+                                           search_base=self.conf['base'],
+                                           search_filter=self.conf['filter'],
+                                           search_scope=self.conf['scope'],
+                                           since=since)
   def GetPasswdMap(self, since=None):
     """Return the passwd map from this source.
 
@@ -673,3 +694,29 @@ class AutomountUpdateGetter(UpdateGetter):
 
     return automount_ent
 
+
+class SshkeyUpdateGetter(UpdateGetter):
+  """Fetches SSH keys."""
+
+  def __init__(self):
+    super(SshkeyUpdateGetter, self).__init__()
+    self.attrs = ['uid', 'sshPublicKey']
+    self.essential_fields = ['uid']
+
+  def CreateMap(self):
+    """Returns a new SshkeyMap instance to have SshkeyMapEntries added to it."""
+    return sshkey.SshkeyMap()
+
+  def Transform(self, obj):
+    """Transforms a LDAP posixAccount data structure into a SshkeyMapEntry."""
+
+    skey = sshkey.SshkeyMapEntry()
+
+    skey.name = obj['uid'][0]
+
+    if 'sshPublicKey' in obj:
+      skey.sshkey = obj['sshPublicKey']
+    else:
+      skey.sshkey = ''
+
+    return skey
